@@ -1,3 +1,5 @@
+from typing import AsyncGenerator
+
 from fastapi import Depends
 from fastapi.security import HTTPAuthorizationCredentials, HTTPBearer
 
@@ -6,5 +8,6 @@ from gateau_api.service import GateauFirebaseService
 
 async def get_service(
     credentials: HTTPAuthorizationCredentials = Depends(HTTPBearer()),
-) -> GateauFirebaseService:
-    return GateauFirebaseService(id_token=credentials.credentials)
+) -> AsyncGenerator[GateauFirebaseService, None]:
+    async with GateauFirebaseService(id_token=credentials.credentials) as service:
+        yield service
